class Hometime
  def self.initialize(duration, start_time)
    @time = start_time
    @duration = duration

    {
      'leave_time': leave_time.strftime('%H:%M'),
      'hours_remaining': unit_formatted('hour', hours),
      'minutes_remaining': unit_formatted('minute', minutes),
      'seconds_remaining': unit_formatted('second', seconds)
    }
  end

  private

  # Time to leave
  def self.leave_time
    Time.new(
        current_time.year,
        current_time.month,
        current_time.day,
        hour, minute, 0
      ) + @duration * 60 * 60
  end

  def self.current_time
    Time.now
  end

  def self.hour
    @time.partition(':').first
  end

  def self.minute
    @time.partition(':').last
  end

  # Time remaining
  def self.unit_formatted(unit, value)
    case
    when value == 1
      "#{value} #{unit} "
    when value > 1 && value < 60
      "#{value} #{unit}s "
    end
  end

  def self.seconds
    (seconds_remaining % 60).floor
  end

  def self.minutes
    ((seconds_remaining / 60) % 60).floor
  end

  def self.hours
    (seconds_remaining / (60 * 60)).floor
  end

  def self.seconds_remaining
    leave_time - current_time
  end

  # TODO - Read important date from file
  def self.important_dates
    file = File.read('../data/dates.json')

    puts "#{days_until_important_date_date} days until Christmas!" if days_until_important_date_date > 0
  end

  def self.important_date_date
    this_year = Time.now.strftime('%Y').to_i
    Time.new(this_year, 12, 25)
  end

  def self.days_until_important_date_date
    ((((important_date_date - current_time) / 60) / 60) / 24).ceil
  end
end
